<?php

class Faq extends FaqsAppModel {

	public $displayField = 'question';
	

	public $belongsTo = array(
		'FaqCategory' => array('className' => 'Faqs.FaqCategory')
	);


	public $validate = array(
		'faq_category_id' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'required'
			)
		),
		'question' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'required'
			),
			'maxLength' => array(
				'rule' => array('maxLength', 250),
				'message' => 'no more than 250 characters long'
			)
		),
		'answer' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'required'
			)
		),
		'sequence' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'required'
			),
			'integer' => array(
				'rule' => array('naturalNumber', true),
				'message' => 'integer values only'
			)
		)
	);


	public $order = array(
		'Faq.sequence' => 'asc',
		'Faq.question' => 'asc'
	);


/**
 * Gets the FAQs grouped by the FAQ categories in sequential order.
 * 
 * @return array
 */
	public function getFaqs() {

		$results = $this->find('all', array(
			'contain' => array(
				'FaqCategory' => array('conditions' => array('FaqCategory.is_active' => true))
			),
			'conditions' => array(
				'Faq.is_active' => true
			),
			'order' => array(
				'FaqCategory.sequence' => 'asc',
				'FaqCategory.name' => 'asc',
				'Faq.sequence' => 'asc',
				'Faq.question' => 'asc'
			)
		));

		$data = array();

		foreach ($results as $result) {

			$id = $result['FaqCategory']['id'];

			if (empty($data[$id])) {

				$data[$id]['FaqCategory'] = $result['FaqCategory'];

			}

			$data[$id]['Faq'][] = $result['Faq'];

		}

		return $data;

	}

}